@@ -12,8 +12,8 @@ use salvo_core::http::{Request, Response, StatusCode};
 use salvo_core::routing::FlowCtrl;
 use salvo_core::writer::Text;
 use salvo_core::{Depot, Handler};
+use serde::{Deserialize, Serialize};
 use serde_json::json;
-use serde::{Serialize, Deserialize};
 
 /// Options
 #[derive(Debug, Clone)]
